# aixiv

[![Release](https://img.shields.io/pypi/v/aixiv?label=Release&color=cornflowerblue&style=flat-square)](https://pypi.org/project/aixiv/)
[![Python](https://img.shields.io/pypi/pyversions/aixiv?label=Python&color=cornflowerblue&style=flat-square)](https://pypi.org/project/aixiv/)
[![Downloads](https://img.shields.io/pypi/dm/aixiv?label=Downloads&color=cornflowerblue&style=flat-square)](https://pepy.tech/project/aixiv)
[![Tests](https://img.shields.io/github/actions/workflow/status/astropenguin/aixiv/tests.yaml?label=Tests&style=flat-square)](https://github.com/astropenguin/aixiv/actions)

Translation and summarization of arXiv by generative AI

## Installation

```shell
pip install aixiv==0.0.1
```
